==> haskell-lucid-2.9.11-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.11
id: lucid-2.9.11-LfVx5oBBZqv8C1aVoYp96O
key: lucid-2.9.11-LfVx5oBBZqv8C1aVoYp96O
license: BSD-3-Clause
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
author: Chris Done
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
abi: c806e803a4a66470fcc419f7d4195b28
exposed: True
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs: /usr/lib/ghc-8.6.3/site-local/lucid-2.9.11
library-dirs: /usr/lib/ghc-8.6.3/site-local/lucid-2.9.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/lucid-2.9.11
hs-libraries: HSlucid-2.9.11-LfVx5oBBZqv8C1aVoYp96O
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mmorph-1.1.2-1XKbJejgVfn63jvndItiSw mtl-2.2.2 text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.9.11-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.11
id: lucid-2.9.11-AYR2OSn1CauCcFtjDeRDP5
key: lucid-2.9.11-AYR2OSn1CauCcFtjDeRDP5
license: BSD-3-Clause
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
author: Chris Done
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
abi: a8c0560ff3cd9db7aae62b1ba28522fd
exposed: True
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs: /usr/lib/ghc-8.6.3/site-local/lucid-2.9.11
library-dirs: /usr/lib/ghc-8.6.3/site-local/lucid-2.9.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/lucid-2.9.11
hs-libraries: HSlucid-2.9.11-AYR2OSn1CauCcFtjDeRDP5
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mmorph-1.1.2-1XKbJejgVfn63jvndItiSw mtl-2.2.2 text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
